netapp_ontap.resources.snapshot API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.snapshot`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

A Snapshot copy is the view of the filesystem as it exists at the time when the Snapshot copy is created.
In ONTAP, different types of Snapshot copies are supported, such as scheduled Snapshot copies, user requested Snapshot copies, SnapMirror Snapshot copies, and so on.
ONTAP Snapshot copy APIs allow you to create, modify, delete and retrieve Snapshot copies.

## Snapshot copy APIs

The following APIs are used to perform operations related to Snapshot copies.

- POST /api/storage/volumes/{volume.uuid}/snapshots
- GET /api/storage/volumes/{volume.uuid}/snapshots
- GET /api/storage/volumes/{volume.uuid}/snapshots/{uuid}
- PATCH /api/storage/volumes/{volume.uuid}/snapshots/{uuid}
- DELETE /api/storage/volumes/{volume.uuid}/snapshots/{uuid}

## Examples

### Creating a Snapshot copy

The POST operation is used to create a Snapshot copy with the specified attributes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snapshot("{volume.uuid}")
        resource.name = "snapshot_copy"
        resource.comment = "Store this copy."
        resource.post(hydrate=True)
        print(resource)

Try it out

    Snapshot(
        {
            "volume": {"name": "v2"},
            "comment": "Store this copy.",
            "svm": {"name": "vs0", "uuid": "8139f958-3c6e-11e9-a45f-005056bbc848"},
            "name": "snapshot_copy",
        }
    )

### Retrieving Snapshot copy attributes

The GET operation is used to retrieve Snapshot copy attributes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Snapshot.get_collection("{volume.uuid}")))

Try it out

    [
        Snapshot(
            {
                "uuid": "402b6c73-73a0-4e89-a58a-75ee0ab3e8c0",
                "_links": {
                    "self": {
                        "href": "/api/storage/volumes/0353dc05-405f-11e9-acb6-005056bbc848/snapshots/402b6c73-73a0-4e89-a58a-75ee0ab3e8c0"
                    }
                },
                "name": "hourly.2019-03-13_1305",
            }
        ),
        Snapshot(
            {
                "uuid": "f0dd497f-efe8-44b7-a4f4-bdd3890bc0c8",
                "_links": {
                    "self": {
                        "href": "/api/storage/volumes/0353dc05-405f-11e9-acb6-005056bbc848/snapshots/f0dd497f-efe8-44b7-a4f4-bdd3890bc0c8"
                    }
                },
                "name": "hourly.2019-03-13_1405",
            }
        ),
        Snapshot(
            {
                "uuid": "02701900-51bd-46b8-9c77-47d9a9e2ce1d",
                "_links": {
                    "self": {
                        "href": "/api/storage/volumes/0353dc05-405f-11e9-acb6-005056bbc848/snapshots/02701900-51bd-46b8-9c77-47d9a9e2ce1d"
                    }
                },
                "name": "hourly.2019-03-13_1522",
            }
        ),
    ]

### Retrieving the attributes of a specific Snapshot copy

The GET operation is used to retrieve the attributes of a specific Snapshot copy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snapshot(
            "0353dc05-405f-11e9-acb6-005056bbc848",
            uuid="402b6c73-73a0-4e89-a58a-75ee0ab3e8c0",
        )
        resource.get()
        print(resource)

Try it out

    Snapshot(
        {
            "uuid": "402b6c73-73a0-4e89-a58a-75ee0ab3e8c0",
            "create_time": "2019-03-13T13:05:00-04:00",
            "volume": {
                "name": "v2",
                "uuid": "0353dc05-405f-11e9-acb6-005056bbc848",
                "_links": {
                    "self": {
                        "href": "/api/storage/volumes/0353dc05-405f-11e9-acb6-005056bbc848"
                    }
                },
            },
            "_links": {
                "self": {
                    "href": "/api/storage/volumes/0353dc05-405f-11e9-acb6-005056bbc848/snapshots/402b6c73-73a0-4e89-a58a-75ee0ab3e8c0"
                }
            },
            "svm": {
                "name": "vs0",
                "uuid": "8139f958-3c6e-11e9-a45f-005056bbc848",
                "_links": {
                    "self": {"href": "/api/svm/svms/8139f958-3c6e-11e9-a45f-005056bbc848"}
                },
            },
            "name": "hourly.2019-03-13_1305",
        }
    )

### Updating a Snapshot copy

The PATCH operation is used to update the specific attributes of a Snapshot copy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snapshot(
            "0353dc05-405f-11e9-acb6-005056bbc848",
            uuid="16f7008c-18fd-4a7d-8485-a0e290d9db7f",
        )
        resource.name = "snapshot_copy_new"
        resource.patch()

### Deleting a Snapshot copy

The DELETE operation is used to delete a Snapshot copy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Snapshot

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Snapshot(
            "0353dc05-405f-11e9-acb6-005056bbc848",
            uuid="16f7008c-18fd-4a7d-8485-a0e290d9db7f",
        )
        resource.delete()

## Classes

`class Snapshot (*args, **kwargs)`

  The Snapshot copy object represents a point in time Snapshot copy of a volume.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a collection of volume Snapshot copies.

    ### Related ONTAP commands

    - `snapshot show`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a Volume Snapshot copy.

    ### Related ONTAP commands

    - `snapshot delete`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a collection of volume Snapshot copies.

    ### Related ONTAP commands

    - `snapshot show`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a collection of volume Snapshot copies.

    ### Related ONTAP commands

    - `snapshot show`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a Volume Snapshot copy.

    ### Related ONTAP commands

    - `snapshot modify`
    - `snapshot rename`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a Volume Snapshot copy.

    ### Related ONTAP commands

    - `snapshot delete`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves details of a specific volume Snapshot copy.

    ### Related ONTAP commands

    - `snapshot show`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a Volume Snapshot copy.

    ### Related ONTAP commands

    - `snapshot modify`
    - `snapshot rename`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a volume Snapshot copy.

    ### Required properties

    - `name` - Name of the Snapshot copy to be created.

    ### Recommended optional properties

    - `comment` - Comment associated with the Snapshot copy.
    - `expiry_time` - Snapshot copies with an expiry time set are not allowed to be deleted until the retention time is reached.
    - `snapmirror_label` - Label for SnapMirror operations.

    ### Related ONTAP commands

    - `snapshot create`

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/snapshots`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class SnapshotSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Snapshot object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `comment GET POST PATCH`

    A comment associated with the Snapshot copy. This is an optional attribute for POST or PATCH.

  `create_time GET`

    Creation time of the Snapshot copy. It is the volume access time when the Snapshot copy was created.

    Example: 2019-02-04T19:00:00.000+0000

  `expiry_time GET POST PATCH`

    The expiry time for the Snapshot copy. This is an optional attribute for POST or PATCH. Snapshot copies with an expiry time set are not allowed to be deleted until the retention time is reached.

    Example: 2019-02-04T19:00:00.000+0000

  `links GET`

    The links field of the snapshot.

  `name GET POST PATCH`

    Snapshot copy. Valid in POST or PATCH.

    Example: this_snapshot

  `owners GET`

    The owners field of the snapshot.

  `snaplock_expiry_time GET`

    SnapLock expiry time for the Snapshot copy, if the Snapshot copy is taken on a SnapLock volume. A Snapshot copy is not allowed to be deleted or renamed until the SnapLock ComplianceClock time goes beyond this retention time.

    Example: 2019-02-04T19:00:00.000+0000

  `snapmirror_label GET POST PATCH`

    Label for SnapMirror operations

  `state GET`

    State of the Snapshot copy. There are cases where some Snapshot copies are not complete. In the "partial" state, the Snapshot copy is consistent but exists only on the subset of the constituents that existed prior to the FlexGroup's expansion. Partial Snapshot copies cannot be used for a Snapshot copy restore operation. A Snapshot copy is in an "invalid" state when it is present in some FlexGroup constituents but not in others. At all other times, a Snapshot copy is valid.

    Valid choices:

    - valid
    - invalid
    - partial
  `svm GET POST PATCH`

    The svm field of the snapshot.

  `uuid GET`

    The UUID of the Snapshot copy in the volume that uniquely identifies the Snapshot copy in that volume.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412

  `volume GET POST PATCH`

    The volume field of the snapshot.